# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EndpointServiceArgs', 'EndpointService']

@pulumi.input_type
class EndpointServiceArgs:
    def __init__(__self__, *,
                 auto_accept_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 payer: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 private_dns_name: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceResourceArgs']]]] = None,
                 service_name_managed: Optional[pulumi.Input[builtins.str]] = None,
                 service_name_suffix: Optional[pulumi.Input[builtins.str]] = None,
                 service_owner: Optional[pulumi.Input[builtins.str]] = None,
                 service_resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 service_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceTagArgs']]]] = None,
                 wildcard_domain_enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a EndpointService resource.
        :param pulumi.Input[builtins.bool] auto_accept_enabled: 是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        :param pulumi.Input[builtins.str] description: 终端节点服务的描述信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_address_versions: 终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        :param pulumi.Input[builtins.str] payer: 私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        :param pulumi.Input[builtins.bool] private_dns_enabled: 终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        :param pulumi.Input[builtins.str] private_dns_name: 终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        :param pulumi.Input[builtins.str] private_dns_type: 私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        :param pulumi.Input[builtins.str] project_name: 终端节点服务所属的项目名称。
        :param pulumi.Input[builtins.str] service_name_managed: 是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        :param pulumi.Input[builtins.str] service_name_suffix: 终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        :param pulumi.Input[builtins.str] service_owner: 当前服务主体。
        :param pulumi.Input[builtins.str] service_resource_type: 服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        :param pulumi.Input[builtins.str] service_type: 终端节点服务的类型。Interface：接口终端节点服务。
        :param pulumi.Input[builtins.bool] wildcard_domain_enabled: 是否启用通配符域名。true：启用。false：未启用。
        """
        if auto_accept_enabled is not None:
            pulumi.set(__self__, "auto_accept_enabled", auto_accept_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_address_versions is not None:
            pulumi.set(__self__, "ip_address_versions", ip_address_versions)
        if payer is not None:
            pulumi.set(__self__, "payer", payer)
        if private_dns_enabled is not None:
            pulumi.set(__self__, "private_dns_enabled", private_dns_enabled)
        if private_dns_name is not None:
            pulumi.set(__self__, "private_dns_name", private_dns_name)
        if private_dns_type is not None:
            pulumi.set(__self__, "private_dns_type", private_dns_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if service_name_managed is not None:
            pulumi.set(__self__, "service_name_managed", service_name_managed)
        if service_name_suffix is not None:
            pulumi.set(__self__, "service_name_suffix", service_name_suffix)
        if service_owner is not None:
            pulumi.set(__self__, "service_owner", service_owner)
        if service_resource_type is not None:
            pulumi.set(__self__, "service_resource_type", service_resource_type)
        if service_type is not None:
            pulumi.set(__self__, "service_type", service_type)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if wildcard_domain_enabled is not None:
            pulumi.set(__self__, "wildcard_domain_enabled", wildcard_domain_enabled)

    @property
    @pulumi.getter(name="autoAcceptEnabled")
    def auto_accept_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        """
        return pulumi.get(self, "auto_accept_enabled")

    @auto_accept_enabled.setter
    def auto_accept_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_accept_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipAddressVersions")
    def ip_address_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        """
        return pulumi.get(self, "ip_address_versions")

    @ip_address_versions.setter
    def ip_address_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_address_versions", value)

    @property
    @pulumi.getter
    def payer(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        """
        return pulumi.get(self, "payer")

    @payer.setter
    def payer(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payer", value)

    @property
    @pulumi.getter(name="privateDnsEnabled")
    def private_dns_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        """
        return pulumi.get(self, "private_dns_enabled")

    @private_dns_enabled.setter
    def private_dns_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "private_dns_enabled", value)

    @property
    @pulumi.getter(name="privateDnsName")
    def private_dns_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        """
        return pulumi.get(self, "private_dns_name")

    @private_dns_name.setter
    def private_dns_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_dns_name", value)

    @property
    @pulumi.getter(name="privateDnsType")
    def private_dns_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_type")

    @private_dns_type.setter
    def private_dns_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_dns_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceResourceArgs']]]]:
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="serviceNameManaged")
    def service_name_managed(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        """
        return pulumi.get(self, "service_name_managed")

    @service_name_managed.setter
    def service_name_managed(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name_managed", value)

    @property
    @pulumi.getter(name="serviceNameSuffix")
    def service_name_suffix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        """
        return pulumi.get(self, "service_name_suffix")

    @service_name_suffix.setter
    def service_name_suffix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name_suffix", value)

    @property
    @pulumi.getter(name="serviceOwner")
    def service_owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        当前服务主体。
        """
        return pulumi.get(self, "service_owner")

    @service_owner.setter
    def service_owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_owner", value)

    @property
    @pulumi.getter(name="serviceResourceType")
    def service_resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        """
        return pulumi.get(self, "service_resource_type")

    @service_resource_type.setter
    def service_resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_resource_type", value)

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的类型。Interface：接口终端节点服务。
        """
        return pulumi.get(self, "service_type")

    @service_type.setter
    def service_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_type", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="wildcardDomainEnabled")
    def wildcard_domain_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用通配符域名。true：启用。false：未启用。
        """
        return pulumi.get(self, "wildcard_domain_enabled")

    @wildcard_domain_enabled.setter
    def wildcard_domain_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "wildcard_domain_enabled", value)


@pulumi.input_type
class _EndpointServiceState:
    def __init__(__self__, *,
                 auto_accept_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 payer: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 private_dns_name: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_name_configuration: Optional[pulumi.Input['EndpointServicePrivateDnsNameConfigurationArgs']] = None,
                 private_dns_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceResourceArgs']]]] = None,
                 service_domain: Optional[pulumi.Input[builtins.str]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name_managed: Optional[pulumi.Input[builtins.str]] = None,
                 service_name_suffix: Optional[pulumi.Input[builtins.str]] = None,
                 service_owner: Optional[pulumi.Input[builtins.str]] = None,
                 service_resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 service_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 wildcard_domain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering EndpointService resources.
        :param pulumi.Input[builtins.bool] auto_accept_enabled: 是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        :param pulumi.Input[builtins.int] billing_type: 终端节点服务的计费类型。0：不计费。3：按量计费。
        :param pulumi.Input[builtins.str] business_status: 终端节点服务是否被锁定。Normal：正常。FinancialLocked：被锁定。说明该参数返回为空时，表示终端节点服务未锁定。
        :param pulumi.Input[builtins.str] create_time: 终端节点服务的创建时间。
        :param pulumi.Input[builtins.str] description: 终端节点服务的描述信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_address_versions: 终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        :param pulumi.Input[builtins.str] payer: 私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        :param pulumi.Input[builtins.bool] private_dns_enabled: 终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        :param pulumi.Input[builtins.str] private_dns_name: 终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        :param pulumi.Input['EndpointServicePrivateDnsNameConfigurationArgs'] private_dns_name_configuration: 终端节点服务私有DNS名称的配置信息。说明PrivateDNSType为private时，不返回该参数。
        :param pulumi.Input[builtins.str] private_dns_type: 私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        :param pulumi.Input[builtins.str] project_name: 终端节点服务所属的项目名称。
        :param pulumi.Input[builtins.str] service_domain: 终端节点服务的服务域名。
        :param pulumi.Input[builtins.str] service_id: 终端节点服务的ID。
        :param pulumi.Input[builtins.str] service_name: 终端节点服务的名称。
        :param pulumi.Input[builtins.str] service_name_managed: 是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        :param pulumi.Input[builtins.str] service_name_suffix: 终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        :param pulumi.Input[builtins.str] service_owner: 当前服务主体。
        :param pulumi.Input[builtins.str] service_resource_type: 服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        :param pulumi.Input[builtins.str] service_type: 终端节点服务的类型。Interface：接口终端节点服务。
        :param pulumi.Input[builtins.str] status: 终端节点服务的状态。Creating：创建中。Pending：配置修改中。Available：可用。Deleting：删除中。
        :param pulumi.Input[builtins.str] update_time: 终端节点服务的最近操作时间。
        :param pulumi.Input[builtins.bool] wildcard_domain_enabled: 是否启用通配符域名。true：启用。false：未启用。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_ids: 终端节点服务提供服务的可用区。说明参数ServiceResourceType返回值为RDSMySQL时，该参数返回空值。
        """
        if auto_accept_enabled is not None:
            pulumi.set(__self__, "auto_accept_enabled", auto_accept_enabled)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_address_versions is not None:
            pulumi.set(__self__, "ip_address_versions", ip_address_versions)
        if payer is not None:
            pulumi.set(__self__, "payer", payer)
        if private_dns_enabled is not None:
            pulumi.set(__self__, "private_dns_enabled", private_dns_enabled)
        if private_dns_name is not None:
            pulumi.set(__self__, "private_dns_name", private_dns_name)
        if private_dns_name_configuration is not None:
            pulumi.set(__self__, "private_dns_name_configuration", private_dns_name_configuration)
        if private_dns_type is not None:
            pulumi.set(__self__, "private_dns_type", private_dns_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if service_domain is not None:
            pulumi.set(__self__, "service_domain", service_domain)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if service_name_managed is not None:
            pulumi.set(__self__, "service_name_managed", service_name_managed)
        if service_name_suffix is not None:
            pulumi.set(__self__, "service_name_suffix", service_name_suffix)
        if service_owner is not None:
            pulumi.set(__self__, "service_owner", service_owner)
        if service_resource_type is not None:
            pulumi.set(__self__, "service_resource_type", service_resource_type)
        if service_type is not None:
            pulumi.set(__self__, "service_type", service_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if wildcard_domain_enabled is not None:
            pulumi.set(__self__, "wildcard_domain_enabled", wildcard_domain_enabled)
        if zone_ids is not None:
            pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="autoAcceptEnabled")
    def auto_accept_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        """
        return pulumi.get(self, "auto_accept_enabled")

    @auto_accept_enabled.setter
    def auto_accept_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_accept_enabled", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        终端节点服务的计费类型。0：不计费。3：按量计费。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务是否被锁定。Normal：正常。FinancialLocked：被锁定。说明该参数返回为空时，表示终端节点服务未锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipAddressVersions")
    def ip_address_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        """
        return pulumi.get(self, "ip_address_versions")

    @ip_address_versions.setter
    def ip_address_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_address_versions", value)

    @property
    @pulumi.getter
    def payer(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        """
        return pulumi.get(self, "payer")

    @payer.setter
    def payer(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payer", value)

    @property
    @pulumi.getter(name="privateDnsEnabled")
    def private_dns_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        """
        return pulumi.get(self, "private_dns_enabled")

    @private_dns_enabled.setter
    def private_dns_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "private_dns_enabled", value)

    @property
    @pulumi.getter(name="privateDnsName")
    def private_dns_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        """
        return pulumi.get(self, "private_dns_name")

    @private_dns_name.setter
    def private_dns_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_dns_name", value)

    @property
    @pulumi.getter(name="privateDnsNameConfiguration")
    def private_dns_name_configuration(self) -> Optional[pulumi.Input['EndpointServicePrivateDnsNameConfigurationArgs']]:
        """
        终端节点服务私有DNS名称的配置信息。说明PrivateDNSType为private时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_name_configuration")

    @private_dns_name_configuration.setter
    def private_dns_name_configuration(self, value: Optional[pulumi.Input['EndpointServicePrivateDnsNameConfigurationArgs']]):
        pulumi.set(self, "private_dns_name_configuration", value)

    @property
    @pulumi.getter(name="privateDnsType")
    def private_dns_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_type")

    @private_dns_type.setter
    def private_dns_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_dns_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceResourceArgs']]]]:
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="serviceDomain")
    def service_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的服务域名。
        """
        return pulumi.get(self, "service_domain")

    @service_domain.setter
    def service_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_domain", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的ID。
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的名称。
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="serviceNameManaged")
    def service_name_managed(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        """
        return pulumi.get(self, "service_name_managed")

    @service_name_managed.setter
    def service_name_managed(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name_managed", value)

    @property
    @pulumi.getter(name="serviceNameSuffix")
    def service_name_suffix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        """
        return pulumi.get(self, "service_name_suffix")

    @service_name_suffix.setter
    def service_name_suffix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name_suffix", value)

    @property
    @pulumi.getter(name="serviceOwner")
    def service_owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        当前服务主体。
        """
        return pulumi.get(self, "service_owner")

    @service_owner.setter
    def service_owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_owner", value)

    @property
    @pulumi.getter(name="serviceResourceType")
    def service_resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        """
        return pulumi.get(self, "service_resource_type")

    @service_resource_type.setter
    def service_resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_resource_type", value)

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的类型。Interface：接口终端节点服务。
        """
        return pulumi.get(self, "service_type")

    @service_type.setter
    def service_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的状态。Creating：创建中。Pending：配置修改中。Available：可用。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointServiceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端节点服务的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="wildcardDomainEnabled")
    def wildcard_domain_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用通配符域名。true：启用。false：未启用。
        """
        return pulumi.get(self, "wildcard_domain_enabled")

    @wildcard_domain_enabled.setter
    def wildcard_domain_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "wildcard_domain_enabled", value)

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        终端节点服务提供服务的可用区。说明参数ServiceResourceType返回值为RDSMySQL时，该参数返回空值。
        """
        return pulumi.get(self, "zone_ids")

    @zone_ids.setter
    def zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "zone_ids", value)


@pulumi.type_token("bytepluscc:privatelink/endpointService:EndpointService")
class EndpointService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_accept_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 payer: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 private_dns_name: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointServiceResourceArgs', 'EndpointServiceResourceArgsDict']]]]] = None,
                 service_name_managed: Optional[pulumi.Input[builtins.str]] = None,
                 service_name_suffix: Optional[pulumi.Input[builtins.str]] = None,
                 service_owner: Optional[pulumi.Input[builtins.str]] = None,
                 service_resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 service_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointServiceTagArgs', 'EndpointServiceTagArgsDict']]]]] = None,
                 wildcard_domain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        终端节点服务是可以与其他VPC通过终端节点建立私网连接的服务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:privatelink/endpointService:EndpointService example "service_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_accept_enabled: 是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        :param pulumi.Input[builtins.str] description: 终端节点服务的描述信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_address_versions: 终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        :param pulumi.Input[builtins.str] payer: 私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        :param pulumi.Input[builtins.bool] private_dns_enabled: 终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        :param pulumi.Input[builtins.str] private_dns_name: 终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        :param pulumi.Input[builtins.str] private_dns_type: 私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        :param pulumi.Input[builtins.str] project_name: 终端节点服务所属的项目名称。
        :param pulumi.Input[builtins.str] service_name_managed: 是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        :param pulumi.Input[builtins.str] service_name_suffix: 终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        :param pulumi.Input[builtins.str] service_owner: 当前服务主体。
        :param pulumi.Input[builtins.str] service_resource_type: 服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        :param pulumi.Input[builtins.str] service_type: 终端节点服务的类型。Interface：接口终端节点服务。
        :param pulumi.Input[builtins.bool] wildcard_domain_enabled: 是否启用通配符域名。true：启用。false：未启用。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EndpointServiceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        终端节点服务是可以与其他VPC通过终端节点建立私网连接的服务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:privatelink/endpointService:EndpointService example "service_id"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_accept_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 payer: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 private_dns_name: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointServiceResourceArgs', 'EndpointServiceResourceArgsDict']]]]] = None,
                 service_name_managed: Optional[pulumi.Input[builtins.str]] = None,
                 service_name_suffix: Optional[pulumi.Input[builtins.str]] = None,
                 service_owner: Optional[pulumi.Input[builtins.str]] = None,
                 service_resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 service_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointServiceTagArgs', 'EndpointServiceTagArgsDict']]]]] = None,
                 wildcard_domain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointServiceArgs.__new__(EndpointServiceArgs)

            __props__.__dict__["auto_accept_enabled"] = auto_accept_enabled
            __props__.__dict__["description"] = description
            __props__.__dict__["ip_address_versions"] = ip_address_versions
            __props__.__dict__["payer"] = payer
            __props__.__dict__["private_dns_enabled"] = private_dns_enabled
            __props__.__dict__["private_dns_name"] = private_dns_name
            __props__.__dict__["private_dns_type"] = private_dns_type
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["resources"] = resources
            __props__.__dict__["service_name_managed"] = service_name_managed
            __props__.__dict__["service_name_suffix"] = service_name_suffix
            __props__.__dict__["service_owner"] = service_owner
            __props__.__dict__["service_resource_type"] = service_resource_type
            __props__.__dict__["service_type"] = service_type
            __props__.__dict__["tags"] = tags
            __props__.__dict__["wildcard_domain_enabled"] = wildcard_domain_enabled
            __props__.__dict__["billing_type"] = None
            __props__.__dict__["business_status"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["private_dns_name_configuration"] = None
            __props__.__dict__["service_domain"] = None
            __props__.__dict__["service_id"] = None
            __props__.__dict__["service_name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
            __props__.__dict__["zone_ids"] = None
        super(EndpointService, __self__).__init__(
            'bytepluscc:privatelink/endpointService:EndpointService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_accept_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ip_address_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            payer: Optional[pulumi.Input[builtins.str]] = None,
            private_dns_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            private_dns_name: Optional[pulumi.Input[builtins.str]] = None,
            private_dns_name_configuration: Optional[pulumi.Input[Union['EndpointServicePrivateDnsNameConfigurationArgs', 'EndpointServicePrivateDnsNameConfigurationArgsDict']]] = None,
            private_dns_type: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointServiceResourceArgs', 'EndpointServiceResourceArgsDict']]]]] = None,
            service_domain: Optional[pulumi.Input[builtins.str]] = None,
            service_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            service_name_managed: Optional[pulumi.Input[builtins.str]] = None,
            service_name_suffix: Optional[pulumi.Input[builtins.str]] = None,
            service_owner: Optional[pulumi.Input[builtins.str]] = None,
            service_resource_type: Optional[pulumi.Input[builtins.str]] = None,
            service_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointServiceTagArgs', 'EndpointServiceTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            wildcard_domain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'EndpointService':
        """
        Get an existing EndpointService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_accept_enabled: 是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        :param pulumi.Input[builtins.int] billing_type: 终端节点服务的计费类型。0：不计费。3：按量计费。
        :param pulumi.Input[builtins.str] business_status: 终端节点服务是否被锁定。Normal：正常。FinancialLocked：被锁定。说明该参数返回为空时，表示终端节点服务未锁定。
        :param pulumi.Input[builtins.str] create_time: 终端节点服务的创建时间。
        :param pulumi.Input[builtins.str] description: 终端节点服务的描述信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_address_versions: 终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        :param pulumi.Input[builtins.str] payer: 私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        :param pulumi.Input[builtins.bool] private_dns_enabled: 终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        :param pulumi.Input[builtins.str] private_dns_name: 终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        :param pulumi.Input[Union['EndpointServicePrivateDnsNameConfigurationArgs', 'EndpointServicePrivateDnsNameConfigurationArgsDict']] private_dns_name_configuration: 终端节点服务私有DNS名称的配置信息。说明PrivateDNSType为private时，不返回该参数。
        :param pulumi.Input[builtins.str] private_dns_type: 私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        :param pulumi.Input[builtins.str] project_name: 终端节点服务所属的项目名称。
        :param pulumi.Input[builtins.str] service_domain: 终端节点服务的服务域名。
        :param pulumi.Input[builtins.str] service_id: 终端节点服务的ID。
        :param pulumi.Input[builtins.str] service_name: 终端节点服务的名称。
        :param pulumi.Input[builtins.str] service_name_managed: 是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        :param pulumi.Input[builtins.str] service_name_suffix: 终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        :param pulumi.Input[builtins.str] service_owner: 当前服务主体。
        :param pulumi.Input[builtins.str] service_resource_type: 服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        :param pulumi.Input[builtins.str] service_type: 终端节点服务的类型。Interface：接口终端节点服务。
        :param pulumi.Input[builtins.str] status: 终端节点服务的状态。Creating：创建中。Pending：配置修改中。Available：可用。Deleting：删除中。
        :param pulumi.Input[builtins.str] update_time: 终端节点服务的最近操作时间。
        :param pulumi.Input[builtins.bool] wildcard_domain_enabled: 是否启用通配符域名。true：启用。false：未启用。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_ids: 终端节点服务提供服务的可用区。说明参数ServiceResourceType返回值为RDSMySQL时，该参数返回空值。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointServiceState.__new__(_EndpointServiceState)

        __props__.__dict__["auto_accept_enabled"] = auto_accept_enabled
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["ip_address_versions"] = ip_address_versions
        __props__.__dict__["payer"] = payer
        __props__.__dict__["private_dns_enabled"] = private_dns_enabled
        __props__.__dict__["private_dns_name"] = private_dns_name
        __props__.__dict__["private_dns_name_configuration"] = private_dns_name_configuration
        __props__.__dict__["private_dns_type"] = private_dns_type
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resources"] = resources
        __props__.__dict__["service_domain"] = service_domain
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["service_name_managed"] = service_name_managed
        __props__.__dict__["service_name_suffix"] = service_name_suffix
        __props__.__dict__["service_owner"] = service_owner
        __props__.__dict__["service_resource_type"] = service_resource_type
        __props__.__dict__["service_type"] = service_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["wildcard_domain_enabled"] = wildcard_domain_enabled
        __props__.__dict__["zone_ids"] = zone_ids
        return EndpointService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoAcceptEnabled")
    def auto_accept_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        """
        return pulumi.get(self, "auto_accept_enabled")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        终端节点服务的计费类型。0：不计费。3：按量计费。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务是否被锁定。Normal：正常。FinancialLocked：被锁定。说明该参数返回为空时，表示终端节点服务未锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ipAddressVersions")
    def ip_address_versions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        """
        return pulumi.get(self, "ip_address_versions")

    @property
    @pulumi.getter
    def payer(self) -> pulumi.Output[builtins.str]:
        """
        私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        """
        return pulumi.get(self, "payer")

    @property
    @pulumi.getter(name="privateDnsEnabled")
    def private_dns_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        """
        return pulumi.get(self, "private_dns_enabled")

    @property
    @pulumi.getter(name="privateDnsName")
    def private_dns_name(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        """
        return pulumi.get(self, "private_dns_name")

    @property
    @pulumi.getter(name="privateDnsNameConfiguration")
    def private_dns_name_configuration(self) -> pulumi.Output['outputs.EndpointServicePrivateDnsNameConfiguration']:
        """
        终端节点服务私有DNS名称的配置信息。说明PrivateDNSType为private时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_name_configuration")

    @property
    @pulumi.getter(name="privateDnsType")
    def private_dns_type(self) -> pulumi.Output[builtins.str]:
        """
        私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence['outputs.EndpointServiceResource']]:
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="serviceDomain")
    def service_domain(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的服务域名。
        """
        return pulumi.get(self, "service_domain")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的ID。
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的名称。
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="serviceNameManaged")
    def service_name_managed(self) -> pulumi.Output[builtins.str]:
        """
        是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        """
        return pulumi.get(self, "service_name_managed")

    @property
    @pulumi.getter(name="serviceNameSuffix")
    def service_name_suffix(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        """
        return pulumi.get(self, "service_name_suffix")

    @property
    @pulumi.getter(name="serviceOwner")
    def service_owner(self) -> pulumi.Output[builtins.str]:
        """
        当前服务主体。
        """
        return pulumi.get(self, "service_owner")

    @property
    @pulumi.getter(name="serviceResourceType")
    def service_resource_type(self) -> pulumi.Output[builtins.str]:
        """
        服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        """
        return pulumi.get(self, "service_resource_type")

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的类型。Interface：接口终端节点服务。
        """
        return pulumi.get(self, "service_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的状态。Creating：创建中。Pending：配置修改中。Available：可用。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.EndpointServiceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        终端节点服务的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="wildcardDomainEnabled")
    def wildcard_domain_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否启用通配符域名。true：启用。false：未启用。
        """
        return pulumi.get(self, "wildcard_domain_enabled")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        终端节点服务提供服务的可用区。说明参数ServiceResourceType返回值为RDSMySQL时，该参数返回空值。
        """
        return pulumi.get(self, "zone_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SnatentryArgs', 'Snatentry']

@pulumi.input_type
class SnatentryArgs:
    def __init__(__self__, *,
                 nat_gateway_id: pulumi.Input[builtins.str],
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Snatentry resource.
        :param pulumi.Input[builtins.str] nat_gateway_id: SNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] eip_id: SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        :param pulumi.Input[builtins.str] nat_ip_id: 私网NAT网关的中转IP的ID。
        :param pulumi.Input[builtins.str] snat_entry_name: SNAT规则的名称。
        :param pulumi.Input[builtins.str] source_cidr: SNAT规则对应的网段。
        :param pulumi.Input[builtins.str] subnet_id: SNAT规则关联子网的ID。
        """
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if snat_entry_name is not None:
            pulumi.set(__self__, "snat_entry_name", snat_entry_name)
        if source_cidr is not None:
            pulumi.set(__self__, "source_cidr", source_cidr)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        SNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网NAT网关的中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_id", value)

    @property
    @pulumi.getter(name="snatEntryName")
    def snat_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则的名称。
        """
        return pulumi.get(self, "snat_entry_name")

    @snat_entry_name.setter
    def snat_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snat_entry_name", value)

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则对应的网段。
        """
        return pulumi.get(self, "source_cidr")

    @source_cidr.setter
    def source_cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_cidr", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则关联子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)


@pulumi.input_type
class _SnatentryState:
    def __init__(__self__, *,
                 eip_address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Snatentry resources.
        :param pulumi.Input[builtins.str] eip_address: SNAT规则关联的公网IP的IP地址。返回单个公网IP的IP地址。 返回多个公网IP的IP地址。
        :param pulumi.Input[builtins.str] eip_id: SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        :param pulumi.Input[builtins.str] nat_gateway_id: SNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] nat_ip_id: 私网NAT网关的中转IP的ID。
        :param pulumi.Input[builtins.str] snat_entry_id: SNAT规则的ID。
        :param pulumi.Input[builtins.str] snat_entry_name: SNAT规则的名称。
        :param pulumi.Input[builtins.str] source_cidr: SNAT规则对应的网段。
        :param pulumi.Input[builtins.str] status: SNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        :param pulumi.Input[builtins.str] subnet_id: SNAT规则关联子网的ID。
        """
        if eip_address is not None:
            pulumi.set(__self__, "eip_address", eip_address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if snat_entry_id is not None:
            pulumi.set(__self__, "snat_entry_id", snat_entry_id)
        if snat_entry_name is not None:
            pulumi.set(__self__, "snat_entry_name", snat_entry_name)
        if source_cidr is not None:
            pulumi.set(__self__, "source_cidr", source_cidr)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则关联的公网IP的IP地址。返回单个公网IP的IP地址。 返回多个公网IP的IP地址。
        """
        return pulumi.get(self, "eip_address")

    @eip_address.setter
    def eip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网NAT网关的中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_id", value)

    @property
    @pulumi.getter(name="snatEntryId")
    def snat_entry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则的ID。
        """
        return pulumi.get(self, "snat_entry_id")

    @snat_entry_id.setter
    def snat_entry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snat_entry_id", value)

    @property
    @pulumi.getter(name="snatEntryName")
    def snat_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则的名称。
        """
        return pulumi.get(self, "snat_entry_name")

    @snat_entry_name.setter
    def snat_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snat_entry_name", value)

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则对应的网段。
        """
        return pulumi.get(self, "source_cidr")

    @source_cidr.setter
    def source_cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_cidr", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNAT规则关联子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)


@pulumi.type_token("bytepluscc:natgateway/snatentry:Snatentry")
class Snatentry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        当私有网络内有多台云服务器实例需要访问公网时，为了节省公网IP且避免在公网上直接暴露云服务器IP，您可以使用公网NAT网关的SNAT规则，安全、便捷、高效地访问公网。SNAT规则支持私有网络、子网、云服务器、自定义网段等四种粒度，您可根据业务需求灵活配置。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_snatentry_demo = bytepluscc.natgateway.Snatentry("NatGatewaySnatentryDemo",
            nat_gateway_id="ngw-2pc28yhdpbx8g227qo1xxxxx",
            eip_id="eip-iivdtssgbdog74o8cuxxxxx,eip-btbv1pk36g3k5h0b2vxxxxx",
            snat_entry_name="私有网络",
            source_cidr="0.0.0.0/0")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/snatentry:Snatentry example "snat_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] eip_id: SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        :param pulumi.Input[builtins.str] nat_gateway_id: SNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] nat_ip_id: 私网NAT网关的中转IP的ID。
        :param pulumi.Input[builtins.str] snat_entry_name: SNAT规则的名称。
        :param pulumi.Input[builtins.str] source_cidr: SNAT规则对应的网段。
        :param pulumi.Input[builtins.str] subnet_id: SNAT规则关联子网的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SnatentryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        当私有网络内有多台云服务器实例需要访问公网时，为了节省公网IP且避免在公网上直接暴露云服务器IP，您可以使用公网NAT网关的SNAT规则，安全、便捷、高效地访问公网。SNAT规则支持私有网络、子网、云服务器、自定义网段等四种粒度，您可根据业务需求灵活配置。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_snatentry_demo = bytepluscc.natgateway.Snatentry("NatGatewaySnatentryDemo",
            nat_gateway_id="ngw-2pc28yhdpbx8g227qo1xxxxx",
            eip_id="eip-iivdtssgbdog74o8cuxxxxx,eip-btbv1pk36g3k5h0b2vxxxxx",
            snat_entry_name="私有网络",
            source_cidr="0.0.0.0/0")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/snatentry:Snatentry example "snat_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param SnatentryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SnatentryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SnatentryArgs.__new__(SnatentryArgs)

            __props__.__dict__["eip_id"] = eip_id
            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            __props__.__dict__["nat_ip_id"] = nat_ip_id
            __props__.__dict__["snat_entry_name"] = snat_entry_name
            __props__.__dict__["source_cidr"] = source_cidr
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["eip_address"] = None
            __props__.__dict__["snat_entry_id"] = None
            __props__.__dict__["status"] = None
        super(Snatentry, __self__).__init__(
            'bytepluscc:natgateway/snatentry:Snatentry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            eip_address: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
            snat_entry_id: Optional[pulumi.Input[builtins.str]] = None,
            snat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
            source_cidr: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Snatentry':
        """
        Get an existing Snatentry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] eip_address: SNAT规则关联的公网IP的IP地址。返回单个公网IP的IP地址。 返回多个公网IP的IP地址。
        :param pulumi.Input[builtins.str] eip_id: SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        :param pulumi.Input[builtins.str] nat_gateway_id: SNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] nat_ip_id: 私网NAT网关的中转IP的ID。
        :param pulumi.Input[builtins.str] snat_entry_id: SNAT规则的ID。
        :param pulumi.Input[builtins.str] snat_entry_name: SNAT规则的名称。
        :param pulumi.Input[builtins.str] source_cidr: SNAT规则对应的网段。
        :param pulumi.Input[builtins.str] status: SNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        :param pulumi.Input[builtins.str] subnet_id: SNAT规则关联子网的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SnatentryState.__new__(_SnatentryState)

        __props__.__dict__["eip_address"] = eip_address
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_ip_id"] = nat_ip_id
        __props__.__dict__["snat_entry_id"] = snat_entry_id
        __props__.__dict__["snat_entry_name"] = snat_entry_name
        __props__.__dict__["source_cidr"] = source_cidr
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        return Snatentry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则关联的公网IP的IP地址。返回单个公网IP的IP地址。 返回多个公网IP的IP地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> pulumi.Output[builtins.str]:
        """
        私网NAT网关的中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="snatEntryId")
    def snat_entry_id(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则的ID。
        """
        return pulumi.get(self, "snat_entry_id")

    @property
    @pulumi.getter(name="snatEntryName")
    def snat_entry_name(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则的名称。
        """
        return pulumi.get(self, "snat_entry_name")

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则对应的网段。
        """
        return pulumi.get(self, "source_cidr")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        SNAT规则关联子网的ID。
        """
        return pulumi.get(self, "subnet_id")

